Module addr

Module addr 

The Address implementation for Block along with related fns for producing the block addr.

Functions

from_block
Shorthand for the common case of producing a block’s content address from a Block.
from_header_and_solution_set_addrs
Given the content address for each solution set in the block, produce the block’s content address.
from_header_and_solution_set_addrs_slice
Given the content address for each solution set in the block, produce the block’s content address.