Functions for constructing keys into the “contract registry” contract state.
Functions
- contract_
predicate_ key - A key that may be used to test if the predicate exists within the contract specified in the
PredicateAddress. - contract_
salt_ key - A key that may be used to refer to a contract’s
saltin state. - predicate_
key - A key that may be used to retrieve the full
Predicatefrom the contract registry state.