pub fn register_contract_solution(
contract_registry: PredicateAddress,
contract: &Contract,
) -> Result<Solution, PredicateEncodeError>Expand description
Create a solution for registering the given contract at the given contract registry.
pub fn register_contract_solution(
contract_registry: PredicateAddress,
contract: &Contract,
) -> Result<Solution, PredicateEncodeError>Create a solution for registering the given contract at the given contract registry.