Functions for constructing keys into the “contract registry” contract state.
Functions
- A key that may be used to test if the predicate exists within the contract specified in the
PredicateAddress. - A key that may be used to refer to a contract’s
saltin state. - A key that may be used to retrieve the full
Predicatefrom the contract registry state.