pub fn register_contract_mutations(
contract: &Contract,
) -> Result<Vec<Mutation>, PredicateEncodeError>Expand description
Generate the mutations required to register a given contract within the big bang’s “contract
registry” contract. This is useful for constructing contract deployment Solutions.
Learn more about the layout of state within the contract registry in
BigBang::contract_registry.