pub fn register_contract_solution(
contract_registry: PredicateAddress,
contract: &Contract,
) -> Result<SolutionData, PredicateError>Expand description
Create a solution for registering the given contract at the given
pub fn register_contract_solution(
contract_registry: PredicateAddress,
contract: &Contract,
) -> Result<SolutionData, PredicateError>Create a solution for registering the given contract at the given