pub fn register_program_mutations(program: &Program) -> Vec<Mutation>Expand description
Generate the mutations required to register a given program within the big bang’s “program
registry” contract. This is useful for constructing program deployment Solutions.
Learn more about the layout of state within the contract registry in
BigBang::program_registry.